EXPORTS
	__DbgTestInvariant__C19CSdpAttrIdMatchList @ 1 NONAME R3UNUSED ; CSdpAttrIdMatchList::__DbgTestInvariant(void) const
	AddAttribute__14CSdpServRecordP8CSdpAttr @ 2 NONAME R3UNUSED ; CSdpServRecord::AddAttribute(CSdpAttr *)
	AddL__17CSdpSearchPatternRC5TUUID @ 3 NONAME R3UNUSED ; CSdpSearchPattern::AddL(TUUID const &)
	AddL__19CSdpAttrIdMatchListG10TAttrRange @ 4 NONAME R3UNUSED ; CSdpAttrIdMatchList::AddL(TAttrRange)
	AddRecord__12CSdpDatabaseP14CSdpServRecord @ 5 NONAME R3UNUSED ; CSdpDatabase::AddRecord(CSdpServRecord *)
	AppendValueL__17CSdpAttrValueListP13CSdpAttrValue @ 6 NONAME R3UNUSED ; CSdpAttrValueList::AppendValueL(CSdpAttrValue *)
	At__C17CSdpSearchPatterni @ 7 NONAME R3UNUSED ; CSdpSearchPattern::At(int) const
	AttrCount__16CSizeAccumulatori @ 8 NONAME R3UNUSED ; CSizeAccumulator::AttrCount(int)
	AttributeOf__16CSizeAccumulatorii @ 9 NONAME R3UNUSED ; CSizeAccumulator::AttributeOf(int, int)
	BufferedParseL__14CElementParserRC6TDesC8 @ 10 NONAME R3UNUSED ; CElementParser::BufferedParseL(TDesC8 const &)
	BuildBooleanL__18MSdpElementBuilderi @ 11 NONAME R3UNUSED ; MSdpElementBuilder::BuildBooleanL(int)
	BuildDEAL__18MSdpElementBuilder @ 12 NONAME R3UNUSED ; MSdpElementBuilder::BuildDEAL(void)
	BuildDESL__18MSdpElementBuilder @ 13 NONAME R3UNUSED ; MSdpElementBuilder::BuildDESL(void)
	BuildIntL__18MSdpElementBuilderRC6TDesC8 @ 14 NONAME R3UNUSED ; MSdpElementBuilder::BuildIntL(TDesC8 const &)
	BuildNilL__18MSdpElementBuilder @ 15 NONAME R3UNUSED ; MSdpElementBuilder::BuildNilL(void)
	BuildStringL__18MSdpElementBuilderRC6TDesC8 @ 16 NONAME R3UNUSED ; MSdpElementBuilder::BuildStringL(TDesC8 const &)
	BuildURLL__18MSdpElementBuilderRC6TDesC8 @ 17 NONAME R3UNUSED ; MSdpElementBuilder::BuildURLL(TDesC8 const &)
	BuildUUIDL__18MSdpElementBuilderRC5TUUID @ 18 NONAME R3UNUSED ; MSdpElementBuilder::BuildUUIDL(TUUID const &)
	BuildUintL__18MSdpElementBuilderRC6TDesC8 @ 19 NONAME R3UNUSED ; MSdpElementBuilder::BuildUintL(TDesC8 const &)
	BuildUnknownL__18MSdpElementBuilderUcUcRC6TDesC8 @ 20 NONAME ; MSdpElementBuilder::BuildUnknownL(unsigned char, unsigned char, TDesC8 const &)
	CHandleItemL__11CHandleItemUlP14CSdpServRecord @ 21 NONAME R3UNUSED ; CHandleItem::CHandleItemL(unsigned long, CSdpServRecord *)
	Close__12RSdpDatabase @ 22 NONAME R3UNUSED ; RSdpDatabase::Close(void)
	Connect__4RSdp @ 23 NONAME R3UNUSED ; RSdp::Connect(void)
	ConstructL__17CSdpSearchPattern @ 24 NONAME R3UNUSED ; CSdpSearchPattern::ConstructL(void)
	Count__C17CSdpSearchPattern @ 25 NONAME R3UNUSED ; CSdpSearchPattern::Count(void) const
	CrcAttribs__16CSizeAccumulator @ 26 NONAME R3UNUSED ; CSizeAccumulator::CrcAttribs(void)
	CreateServiceRecordL__12RSdpDatabaseR16CSdpAttrValueDESRUl @ 27 NONAME R3UNUSED ; RSdpDatabase::CreateServiceRecordL(CSdpAttrValueDES &, unsigned long &)
	CreateServiceRecordL__12RSdpDatabaseRC5TUUIDRUl @ 28 NONAME R3UNUSED ; RSdpDatabase::CreateServiceRecordL(TUUID const &, unsigned long &)
	DeleteAttributeL__12RSdpDatabaseUlUs @ 29 NONAME R3UNUSED ; RSdpDatabase::DeleteAttributeL(unsigned long, unsigned short)
	DeleteRecordL__12RSdpDatabaseUl @ 30 NONAME R3UNUSED ; RSdpDatabase::DeleteRecordL(unsigned long)
	EncodeAttributeL__19CAttrEncoderVisitorR15CElementEncoderR13CSdpAttrValue @ 31 NONAME R3UNUSED ; CAttrEncoderVisitor::EncodeAttributeL(CElementEncoder &, CSdpAttrValue &)
	EncodeAttributesL__19CAttrExtractVisitorR15CElementEncoderR14CSdpServRecordR19CSdpAttrIdMatchList @ 32 NONAME R3UNUSED ; CAttrExtractVisitor::EncodeAttributesL(CElementEncoder &, CSdpServRecord &, CSdpAttrIdMatchList &)
	EncodeDbL__12CSdpDatabase @ 33 NONAME R3UNUSED ; CSdpDatabase::EncodeDbL(void)
	EncodeL__C19CSdpAttrIdMatchListR15CElementEncoder @ 34 NONAME R3UNUSED ; CSdpAttrIdMatchList::EncodeL(CElementEncoder &) const
	EncodedSize__15CElementEncoder15TSdpElementTypeUi @ 35 NONAME R3UNUSED ; CElementEncoder::EncodedSize(TSdpElementType, unsigned int)
	EndListL__18MSdpElementBuilder @ 36 NONAME R3UNUSED ; MSdpElementBuilder::EndListL(void)
	Find__C17CSdpSearchPatternRC5TUUIDRi @ 37 NONAME R3UNUSED ; CSdpSearchPattern::Find(TUUID const &, int &) const
	HandleAt__16CSizeAccumulatori @ 38 NONAME R3UNUSED ; CSizeAccumulator::HandleAt(int)
	HandleCount__16CSizeAccumulator @ 39 NONAME R3UNUSED ; CSizeAccumulator::HandleCount(void)
	HandleSize__16CSizeAccumulatori @ 40 NONAME R3UNUSED ; CSizeAccumulator::HandleSize(int)
	Handle__C14CSdpServRecord @ 41 NONAME R3UNUSED ; CSdpServRecord::Handle(void) const
	HeaderSize__15CElementEncoder15TSdpElementTypeUi @ 42 NONAME R3UNUSED ; CElementEncoder::HeaderSize(TSdpElementType, unsigned int)
	InMatchList__C19CSdpAttrIdMatchListUsRi @ 43 NONAME R3UNUSED ; CSdpAttrIdMatchList::InMatchList(unsigned short, int &) const
	NewBoolL__20CSdpAttrValueBooleani @ 44 NONAME R3UNUSED ; CSdpAttrValueBoolean::NewBoolL(int)
	NewDEAL__16CSdpAttrValueDEAP18MSdpElementBuilder @ 45 NONAME R3UNUSED ; CSdpAttrValueDEA::NewDEAL(MSdpElementBuilder *)
	NewDESL__16CSdpAttrValueDESP18MSdpElementBuilder @ 46 NONAME R3UNUSED ; CSdpAttrValueDES::NewDESL(MSdpElementBuilder *)
	NewEncodedL__20CSdpAttrValueEncodedRC6TDesC8 @ 47 NONAME R3UNUSED ; CSdpAttrValueEncoded::NewEncodedL(TDesC8 const &)
	NewIntL__16CSdpAttrValueIntRC6TDesC8 @ 48 NONAME R3UNUSED ; CSdpAttrValueInt::NewIntL(TDesC8 const &)
	NewLC__11CHandleItem @ 49 NONAME R3UNUSED ; CHandleItem::NewLC(void)
	NewLC__12CSdpDatabase @ 50 NONAME R3UNUSED ; CSdpDatabase::NewLC(void)
	NewLC__16CSizeAccumulator @ 51 NONAME R3UNUSED ; CSizeAccumulator::NewLC(void)
	NewLC__21CServiceSearchVisitorRC17CSdpSearchPattern @ 52 NONAME R3UNUSED ; CServiceSearchVisitor::NewLC(CSdpSearchPattern const &)
	NewL__11CHandleItem @ 53 NONAME R3UNUSED ; CHandleItem::NewL(void)
	NewL__12CSdpDatabase @ 54 NONAME R3UNUSED ; CSdpDatabase::NewL(void)
	NewL__14CElementParserP18MSdpElementBuilder @ 55 NONAME R3UNUSED ; CElementParser::NewL(MSdpElementBuilder *)
	NewL__14CSdpServRecord @ 56 NONAME R3UNUSED ; CSdpServRecord::NewL(void)
	NewL__16CSizeAccumulator @ 57 NONAME R3UNUSED ; CSizeAccumulator::NewL(void)
	NewL__17CSdpSearchPattern @ 58 NONAME R3UNUSED ; CSdpSearchPattern::NewL(void)
	NewL__19CSdpAttrIdMatchList @ 59 NONAME R3UNUSED ; CSdpAttrIdMatchList::NewL(void)
	NewL__19CSdpAttrIdMatchListRC19CSdpAttrIdMatchList @ 60 NONAME R3UNUSED ; CSdpAttrIdMatchList::NewL(CSdpAttrIdMatchList const &)
	NewL__21CServiceSearchVisitorRC17CSdpSearchPattern @ 61 NONAME R3UNUSED ; CServiceSearchVisitor::NewL(CSdpSearchPattern const &)
	NewL__8CSdpAttrUsP18MSdpElementBuilder @ 62 NONAME R3UNUSED ; CSdpAttr::NewL(unsigned short, MSdpElementBuilder *)
	NewNilL__16CSdpAttrValueNil @ 63 NONAME R3UNUSED ; CSdpAttrValueNil::NewNilL(void)
	NewRecordL__12CSdpDatabase @ 64 NONAME R3UNUSED ; CSdpDatabase::NewRecordL(void)
	NewStringL__19CSdpAttrValueStringRC6TDesC8 @ 65 NONAME R3UNUSED ; CSdpAttrValueString::NewStringL(TDesC8 const &)
	NewURLL__16CSdpAttrValueURLRC6TDesC8 @ 66 NONAME R3UNUSED ; CSdpAttrValueURL::NewURLL(TDesC8 const &)
	NewUUIDL__17CSdpAttrValueUUIDRC5TUUID @ 67 NONAME R3UNUSED ; CSdpAttrValueUUID::NewUUIDL(TUUID const &)
	NewUintL__17CSdpAttrValueUintRC6TDesC8 @ 68 NONAME R3UNUSED ; CSdpAttrValueUint::NewUintL(TDesC8 const &)
	NextFreeHandle__12CSdpDatabase @ 69 NONAME R3UNUSED ; CSdpDatabase::NextFreeHandle(void)
	Open__12RSdpDatabaseR4RSdp @ 70 NONAME R3UNUSED ; RSdpDatabase::Open(RSdp &)
	ParseDbL_Obscelete_DoesNothing__12CSdpDatabase @ 71 NONAME R3UNUSED ; CSdpDatabase::ParseDbL_Obscelete_DoesNothing(void)
	ParseElementsL__14CElementParserRC6TDesC8 @ 72 NONAME R3UNUSED ; CElementParser::ParseElementsL(TDesC8 const &)
	PutUint__15CElementEncoderPUcUii @ 73 NONAME R3UNUSED ; CElementEncoder::PutUint(unsigned char *, unsigned int, int)
	PutUint__7SdpUtilPUcG6TInt64i @ 74 NONAME ; SdpUtil::PutUint(unsigned char *, TInt64, int)
	RemoveL__19CSdpAttrIdMatchListG10TAttrRange @ 75 NONAME R3UNUSED ; CSdpAttrIdMatchList::RemoveL(TAttrRange)
	Remove__17CSdpSearchPatternRC5TUUID @ 76 NONAME R3UNUSED ; CSdpSearchPattern::Remove(TUUID const &)
	Reset__14CElementParser @ 77 NONAME R3UNUSED ; CElementParser::Reset(void)
	Reset__14CElementParserP18MSdpElementBuilder @ 78 NONAME R3UNUSED ; CElementParser::Reset(MSdpElementBuilder *)
	Reset__17CSdpSearchPattern @ 79 NONAME R3UNUSED ; CSdpSearchPattern::Reset(void)
	ResourceCountMarkEnd__4RSdp @ 80 NONAME R3UNUSED ; RSdp::ResourceCountMarkEnd(void)
	ResourceCountMarkStart__4RSdp @ 81 NONAME R3UNUSED ; RSdp::ResourceCountMarkStart(void)
	ResourceCount__4RSdp @ 82 NONAME R3UNUSED ; RSdp::ResourceCount(void)
	SearchDbL__21CServiceSearchVisitorR12CSdpDatabaseRC17CSdpSearchPatternR21MServiceSearchHandler @ 83 NONAME R3UNUSED ; CServiceSearchVisitor::SearchDbL(CSdpDatabase &, CSdpSearchPattern const &, MServiceSearchHandler &)
	SizeDescriptor__15CElementEncoder15TSdpElementTypeUi @ 84 NONAME R3UNUSED ; CElementEncoder::SizeDescriptor(TSdpElementType, unsigned int)
	SizeLeft__16CSizeAccumulator @ 85 NONAME R3UNUSED ; CSizeAccumulator::SizeLeft(void)
	SizeRespARL__20CResponseSizeVisitorR14CSdpServRecordRC19CSdpAttrIdMatchListR16CSizeAccumulator @ 86 NONAME R3UNUSED ; CResponseSizeVisitor::SizeRespARL(CSdpServRecord &, CSdpAttrIdMatchList const &, CSizeAccumulator &)
	SizeRespSAL__20CResponseSizeVisitorR12CSdpDatabaseRC17CSdpSearchPatternRC19CSdpAttrIdMatchListR16CSizeAccumulator @ 87 NONAME ; CResponseSizeVisitor::SizeRespSAL(CSdpDatabase &, CSdpSearchPattern const &, CSdpAttrIdMatchList const &, CSizeAccumulator &)
	SizeRespSSL__20CResponseSizeVisitorR12CSdpDatabaseRC17CSdpSearchPatternR16CSizeAccumulator @ 88 NONAME R3UNUSED ; CResponseSizeVisitor::SizeRespSSL(CSdpDatabase &, CSdpSearchPattern const &, CSizeAccumulator &)
	StartAt__16CSizeAccumulatorUiRUiRiT3 @ 89 NONAME ; CSizeAccumulator::StartAt(unsigned int, unsigned int &, int &, int &)
	StartListL__18MSdpElementBuilder @ 90 NONAME R3UNUSED ; MSdpElementBuilder::StartListL(void)
	UpdateAttributeL__12RSdpDatabaseUlUsR13CSdpAttrValue @ 91 NONAME ; RSdpDatabase::UpdateAttributeL(unsigned long, unsigned short, CSdpAttrValue &)
	UpdateAttributeL__12RSdpDatabaseUlUsRC6TDesC8 @ 92 NONAME ; RSdpDatabase::UpdateAttributeL(unsigned long, unsigned short, TDesC8 const &)
	UpdateAttributeL__12RSdpDatabaseUlUsRC7TDesC16 @ 93 NONAME ; RSdpDatabase::UpdateAttributeL(unsigned long, unsigned short, TDesC16 const &)
	UpdateAttributeL__12RSdpDatabaseUlUsUi @ 94 NONAME ; RSdpDatabase::UpdateAttributeL(unsigned long, unsigned short, unsigned int)
	Version__C4RSdp @ 95 NONAME R3UNUSED ; RSdp::Version(void) const
	WriteBoolean__15CElementEncoderi @ 96 NONAME R3UNUSED ; CElementEncoder::WriteBoolean(int)
	WriteDEA__15CElementEncoderUi @ 97 NONAME R3UNUSED ; CElementEncoder::WriteDEA(unsigned int)
	WriteDES__15CElementEncoderUi @ 98 NONAME R3UNUSED ; CElementEncoder::WriteDES(unsigned int)
	WriteDesc__15CElementEncoderRC6TDesC8 @ 99 NONAME R3UNUSED ; CElementEncoder::WriteDesc(TDesC8 const &)
	WriteElement__15CElementEncoder15TSdpElementTypeRC6TDesC8 @ 100 NONAME R3UNUSED ; CElementEncoder::WriteElement(TSdpElementType, TDesC8 const &)
	WriteHeader__15CElementEncoder15TSdpElementTypeUi @ 101 NONAME R3UNUSED ; CElementEncoder::WriteHeader(TSdpElementType, unsigned int)
	WriteInt__15CElementEncoderRC6TDesC8 @ 102 NONAME R3UNUSED ; CElementEncoder::WriteInt(TDesC8 const &)
	WriteInt__15CElementEncoderii @ 103 NONAME R3UNUSED ; CElementEncoder::WriteInt(int, int)
	WriteNil__15CElementEncoder @ 104 NONAME R3UNUSED ; CElementEncoder::WriteNil(void)
	WriteString__15CElementEncoderRC6TDesC8 @ 105 NONAME R3UNUSED ; CElementEncoder::WriteString(TDesC8 const &)
	WriteURL__15CElementEncoderRC6TDesC8 @ 106 NONAME R3UNUSED ; CElementEncoder::WriteURL(TDesC8 const &)
	WriteUUID__15CElementEncoderRC5TUUID @ 107 NONAME R3UNUSED ; CElementEncoder::WriteUUID(TUUID const &)
	WriteUint__15CElementEncoderRC6TDesC8 @ 108 NONAME R3UNUSED ; CElementEncoder::WriteUint(TDesC8 const &)
	WriteUint__15CElementEncoderUii @ 109 NONAME R3UNUSED ; CElementEncoder::WriteUint(unsigned int, int)
	"_._11CRecordAttr" @ 110 NONAME R3UNUSED ; CRecordAttr::~CRecordAttr(void)
	"_._12CSdpDatabase" @ 111 NONAME R3UNUSED ; CSdpDatabase::~CSdpDatabase(void)
	"_._14CElementParser" @ 112 NONAME R3UNUSED ; CElementParser::~CElementParser(void)
	"_._17CSdpSearchPattern" @ 113 NONAME R3UNUSED ; CSdpSearchPattern::~CSdpSearchPattern(void)
	"_._19CSdpAttrIdMatchList" @ 114 NONAME R3UNUSED ; CSdpAttrIdMatchList::~CSdpAttrIdMatchList(void)
	__11CRecordAttr @ 115 NONAME R3UNUSED ; CRecordAttr::CRecordAttr(void)
	__12RSdpDatabase @ 116 NONAME R3UNUSED ; RSdpDatabase::RSdpDatabase(void)
	__15CElementEncoderR5TDes8 @ 117 NONAME R3UNUSED ; CElementEncoder::CElementEncoder(TDes8 &)
	__22CBuilderAdapterVisitorP18MSdpElementBuilder @ 118 NONAME R3UNUSED ; CBuilderAdapterVisitor::CBuilderAdapterVisitor(MSdpElementBuilder *)
	__4RSdp @ 119 NONAME R3UNUSED ; RSdp::RSdp(void)
	AcceptVisitorL__8CSdpAttrR17MAttributeVisitor @ 120 NONAME R3UNUSED ; CSdpAttr::AcceptVisitorL(MAttributeVisitor &)
	ClientUid__C14CSdpServRecord @ 121 NONAME ; CSdpServRecord::ClientUid(void) const
	NewServerSideL__14CSdpServRecordRC4TUid @ 122 NONAME ; CSdpServRecord::NewServerSideL(TUid const &)

